@@ -64,8 +64,8 @@ from orangecontrib.shadow.util.shadow_objects import ShadowBeam
 from orangecontrib.shadow.util.shadow_util import ShadowCongruence, ShadowPlot
 from orangecontrib.shadow.widgets.gui import ow_automatic_element
 
-from orangecontrib.aps.util.gui import StatisticalDataCollection, HistogramDataCollection, DoublePlotWidget, write_histo_and_stats_file_hdf5, write_histo_and_stats_file
-from orangecontrib.aps.shadow.util.gui import ScanHistoWidget, Scan3DHistoWidget
+from oasys.util.scanning_gui import StatisticalDataCollection, HistogramDataCollection, DoublePlotWidget, write_histo_and_stats_file_hdf5, write_histo_and_stats_file
+from orangecontrib.shadow.util.scanning_gui import ScanHistoWidget, Scan3DHistoWidget
 
 class Histogram(ow_automatic_element.AutomaticElement):
 
